Module reader

Module reader 

Module for reading JSON data

JsonReader is the general trait for JSON readers, JsonStreamReader is an implementation of it which reads a JSON document from a Read in a streaming way.

Modules

json_path
Module for ‘JSON path’
simplesimple-api
JSON reader variant which is easier to use than JsonReader

Structs

JsonReaderPosition
Position of the JSON reader in the JSON document
JsonStreamReader
A JSON reader implementation which consumes data from a Read
JsonSyntaxError
JSON syntax error
LinePosition
Line and column position
ReaderSettings
Settings to customize the JSON reader behavior

Enums

ReaderError
Error which occurred while reading from a JSON reader
SyntaxErrorKind
Describes why a syntax error occurred
TransferError
Error which occurred while calling JsonReader::transfer_to
UnexpectedStructureKind
Describes why the JSON document is considered to have an unexpected structure
ValueType
Type of a JSON value

Traits

JsonReader
A trait for JSON readers