Module struson::reader::simple

source ·
Available on crate feature experimental only.
JSON reader variant which is easier to use than JsonReader

The main entrypoint is SimpleJsonReader, all other structs and traits are used by it for reading certain JSON value types.


🔬 Experimental
This API and the naming is currently experimental, please provide feedback here. Any feedback is appreciated!

Modules

Structs

Traits