pub struct ArrayReader<'a, J: JsonReader> { /* private fields */ }
Available on crate feature experimental only.
Reader for an arbitrary amount of JSON array items

This struct is used by ValueReader::read_array.

Implementations

source

impl<J: JsonReader> ArrayReader<'_, J>

source

pub fn has_next(&mut self) -> Result<bool, ReaderError>

Checks if there is a next item in the JSON array, without consuming it

Returns true if there is a next item, false otherwise. This method can be useful as condition of a while loop when processing a JSON array of unknown size.

Examples
let json_reader = SimpleJsonReader::new("[1, 2]".as_bytes());
json_reader.read_array(|array_reader| {
    while array_reader.has_next()? {
        let value = array_reader.read_number_as_string()?;
        println!("{value}");
    }
    Ok(())
})?;