Module for reading JSON data
JsonReader is the general trait for JSON readers, JsonStreamReader is an implementation
of it which reads a JSON document from a Read in a streaming way.
Modules
- json_
path - Module for ‘JSON path’
- simple
simple-api - JSON reader variant which is easier to use than
JsonReader
Structs
- Json
Reader Position - Position of the JSON reader in the JSON document
- Json
Stream Reader - A JSON reader implementation which consumes data from a
Read - Json
Syntax Error - JSON syntax error
- Line
Position - Line and column position
- Reader
Settings - Settings to customize the JSON reader behavior
Enums
- Reader
Error - Error which occurred while reading from a JSON reader
- Syntax
Error Kind - Describes why a syntax error occurred
- Transfer
Error - Error which occurred while calling
JsonReader::transfer_to - Unexpected
Structure Kind - Describes why the JSON document is considered to have an unexpected structure
- Value
Type - Type of a JSON value
Traits
- Json
Reader - A trait for JSON readers