Available on crate feature
experimental only.Expand description
JSON reader variant which is easier to use than JsonReader
The main entrypoint is SimpleJsonReader, all other structs and traits
are used by it for reading certain JSON value types.
🔬 Experimental
This API and the naming is currently experimental, please provide feedback here.
Any feedback is appreciated!
Modules
- Module for ‘multi JSON path’
Structs
- Reader for an arbitrary amount of JSON array items
- Reader for a JSON object member
- JSON reader variant which is easier to use than
JsonReader - Reader for a single JSON value
- Reader for a JSON string value
Traits
- Reader for a JSON value